<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{
        width: 100%;
        height: 100%
      }

    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "Arkansas";
    var qsoPartyUrl = "http://arkanhams.org/QSOParty.htm";
    var overlayUrl = "http://www.no5w.com/OverlayArkansasRev5.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Arkansas", "arka");
  countySelection.options[1] = new Option("Ashley", "ashl");
  countySelection.options[2] = new Option("Baxter", "baxt");
  countySelection.options[3] = new Option("Benton", "bent");
  countySelection.options[4] = new Option("Boone", "boon");
  countySelection.options[5] = new Option("Bradley", "brad");
  countySelection.options[6] = new Option("Calhoun", "calh");
  countySelection.options[7] = new Option("Carroll", "carr");
  countySelection.options[8] = new Option("Chicot", "chic");
  countySelection.options[9] = new Option("Clark", "clrk");
  countySelection.options[10] = new Option("Clay", "clay");
  countySelection.options[11] = new Option("Cleburne", "cleb");
  countySelection.options[12] = new Option("Cleveland", "clev");
  countySelection.options[13] = new Option("Columbia", "colu");
  countySelection.options[14] = new Option("Conway", "conw");
  countySelection.options[15] = new Option("Craighead", "crag");
  countySelection.options[16] = new Option("Crawford", "craw");
  countySelection.options[17] = new Option("Crittenden", "crit");
  countySelection.options[18] = new Option("Cross", "cros");
  countySelection.options[19] = new Option("Dallas", "dall");
  countySelection.options[20] = new Option("Desha", "desh");
  countySelection.options[21] = new Option("Drew", "drew");
  countySelection.options[22] = new Option("Faulkner", "faul");
  countySelection.options[23] = new Option("Franklin", "frnk");
  countySelection.options[24] = new Option("Fulton", "fult");
  countySelection.options[25] = new Option("Garland", "garl");
  countySelection.options[26] = new Option("Grant", "grnt");
  countySelection.options[27] = new Option("Greene", "gren");
  countySelection.options[28] = new Option("Hempstead", "hemp");
  countySelection.options[29] = new Option("HotSpring", "hspr");
  countySelection.options[30] = new Option("Howard", "howa");
  countySelection.options[31] = new Option("Independence", "inde");
  countySelection.options[32] = new Option("Izard", "izrd");
  countySelection.options[33] = new Option("Jackson", "jack");
  countySelection.options[34] = new Option("Jefferson", "jeff");
  countySelection.options[35] = new Option("Johnson", "john");
  countySelection.options[36] = new Option("Lafayette", "lafa");
  countySelection.options[37] = new Option("Lawrence", "lawr");
  countySelection.options[38] = new Option("Lee", "lee");
  countySelection.options[39] = new Option("Lincoln", "linc");
  countySelection.options[40] = new Option("LittleRiver", "lrvr");
  countySelection.options[41] = new Option("Logan", "logn");
  countySelection.options[42] = new Option("Lonoke", "lono");
  countySelection.options[43] = new Option("Madison", "madi");
  countySelection.options[44] = new Option("Marion", "mari");
  countySelection.options[45] = new Option("Miller", "mill");
  countySelection.options[46] = new Option("Mississippi", "miss");
  countySelection.options[47] = new Option("Monroe", "monr");
  countySelection.options[48] = new Option("Montgomery", "mtgy");
  countySelection.options[49] = new Option("Nevada", "neva");
  countySelection.options[50] = new Option("Newton", "newt");
  countySelection.options[51] = new Option("Ouachita", "ouac");
  countySelection.options[52] = new Option("Perry", "perr");
  countySelection.options[53] = new Option("Phillips", "phil");
  countySelection.options[54] = new Option("Pike", "pike");
  countySelection.options[55] = new Option("Poinsett", "poin");
  countySelection.options[56] = new Option("Polk", "polk");
  countySelection.options[57] = new Option("Pope", "pope");
  countySelection.options[58] = new Option("Prairie", "prar");
  countySelection.options[59] = new Option("Pulaski", "pula");
  countySelection.options[60] = new Option("Randolph", "rand");
  countySelection.options[61] = new Option("Saline", "sali");
  countySelection.options[62] = new Option("Scott", "scot");
  countySelection.options[63] = new Option("Searcy", "srcy");
  countySelection.options[64] = new Option("Sebastian", "seba");
  countySelection.options[65] = new Option("Sevier", "sevr");
  countySelection.options[66] = new Option("Sharp", "shrp");
  countySelection.options[67] = new Option("St.Francis", "stfr");
  countySelection.options[68] = new Option("Stone", "ston");
  countySelection.options[69] = new Option("Union", "unio");
  countySelection.options[70] = new Option("VanBuren", "vbrn");
  countySelection.options[71] = new Option("Washington", "wash");
  countySelection.options[72] = new Option("White", "whie");
  countySelection.options[73] = new Option("Woodruff", "wood");
  countySelection.options[74] = new Option("Yell", "yell");
  addMarker(34.25270000, -91.38200000, "Arkansas", "arka");
  addMarker(33.20210000, -91.80050000, "Ashley", "ashl");
  addMarker(36.23640000, -92.37260000, "Baxter", "baxt");
  addMarker(36.29950000, -94.21670000, "Benton", "bent");
  addMarker(36.30620000, -93.07750000, "Boone", "boon");
  addMarker(33.43450000, -92.17100000, "Bradley", "brad");
  addMarker(33.53600000, -92.54390000, "Calhoun", "calh");
  addMarker(36.31020000, -93.59320000, "Carroll", "carr");
  addMarker(33.28390000, -91.25210000, "Chicot", "chic");
  addMarker(34.05550000, -93.18940000, "Clark", "clrk");
  addMarker(36.34960000, -90.43530000, "Clay", "clay");
  addMarker(35.53520000, -92.02130000, "Cleburne", "cleb");
  addMarker(33.88420000, -92.21440000, "Cleveland", "clev");
  addMarker(33.23620000, -93.23450000, "Columbia", "colu");
  addMarker(35.26710000, -92.76030000, "Conway", "conw");
  addMarker(35.84820000, -90.66180000, "Craighead", "crag");
  addMarker(35.55760000, -94.19260000, "Crawford", "craw");
  addMarker(35.13740000, -90.28550000, "Crittenden", "crit");
  addMarker(35.29650000, -90.77240000, "Cross", "cros");
  addMarker(33.97550000, -92.64780000, "Dallas", "dall");
  addMarker(33.81820000, -91.21410000, "Desha", "desh");
  addMarker(33.59060000, -91.73280000, "Drew", "drew");
  addMarker(35.10530000, -92.35490000, "Faulkner", "faul");
  addMarker(35.48690000, -93.88940000, "Franklin", "frnk");
  addMarker(36.37470000, -91.80460000, "Fulton", "fult");
  addMarker(34.58130000, -93.09940000, "Garland", "garl");
  addMarker(34.27770000, -92.44310000, "Grant", "grnt");
  addMarker(36.11630000, -90.52510000, "Greene", "gren");
  addMarker(33.74250000, -93.71320000, "Hempstead", "hemp");
  addMarker(34.32790000, -93.03840000, "HotSpring", "hspr");
  addMarker(34.05170000, -94.03840000, "Howard", "howa");
  addMarker(35.73460000, -91.53480000, "Independence", "inde");
  addMarker(36.06430000, -91.94470000, "Izard", "izrd");
  addMarker(35.62210000, -91.30860000, "Jackson", "jack");
  addMarker(34.27750000, -91.83250000, "Jefferson", "jeff");
  addMarker(35.54770000, -93.43730000, "Johnson", "john");
  addMarker(33.25020000, -93.61290000, "Lafayette", "lafa");
  addMarker(36.06940000, -91.05240000, "Lawrence", "lawr");
  addMarker(34.76970000, -90.75520000, "Lee", "lee");
  addMarker(33.97870000, -91.69910000, "Lincoln", "linc");
  addMarker(33.73950000, -94.15520000, "LittleRiver", "lrvr");
  addMarker(35.22490000, -93.71010000, "Logan", "logn");
  addMarker(34.77910000, -91.87740000, "Lonoke", "lono");
  addMarker(36.03360000, -93.70430000, "Madison", "madi");
  addMarker(36.28070000, -92.64890000, "Marion", "mari");
  addMarker(33.31660000, -93.85450000, "Miller", "mill");
  addMarker(35.70360000, -89.96680000, "Mississippi", "miss");
  addMarker(34.67020000, -91.22410000, "Monroe", "monr");
  addMarker(34.54300000, -93.66460000, "Montgomery", "mtgy");
  addMarker(33.70080000, -93.29410000, "Nevada", "neva");
  addMarker(35.92490000, -93.23230000, "Newton", "newt");
  addMarker(33.58900000, -92.84270000, "Ouachita", "ouac");
  addMarker(34.94390000, -92.92320000, "Perry", "perr");
  addMarker(34.38230000, -90.82930000, "Phillips", "phil");
  addMarker(34.14670000, -93.65520000, "Pike", "pike");
  addMarker(35.57360000, -90.66280000, "Poinsett", "poin");
  addMarker(34.45940000, -94.20020000, "Polk", "polk");
  addMarker(35.42320000, -93.05440000, "Pope", "pope");
  addMarker(34.78560000, -91.57380000, "Prairie", "prar");
  addMarker(34.75190000, -92.39250000, "Pulaski", "pula");
  addMarker(36.30670000, -91.07790000, "Randolph", "rand");
  addMarker(34.63610000, -92.65970000, "Saline", "sali");
  addMarker(34.88260000, -94.07970000, "Scott", "scot");
  addMarker(35.91680000, -92.68140000, "Searcy", "srcy");
  addMarker(35.19100000, -94.23820000, "Sebastian", "seba");
  addMarker(33.97180000, -94.21800000, "Sevier", "sevr");
  addMarker(36.19410000, -91.48470000, "Sharp", "shrp");
  addMarker(35.00810000, -90.77650000, "St.Francis", "stfr");
  addMarker(35.91900000, -92.12720000, "Stone", "ston");
  addMarker(33.19700000, -92.52890000, "Union", "unio");
  addMarker(35.57730000, -92.54560000, "VanBuren", "vbrn");
  addMarker(35.99400000, -94.22000000, "Washington", "wash");
  addMarker(35.27760000, -91.73250000, "White", "whie");
  addMarker(35.17910000, -91.25940000, "Woodruff", "wood");
  addMarker(35.03040000, -93.30320000, "Yell", "yell");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

